#!/usr/bin/python3

import os
from PyQt6.QtWidgets import QTabWidget
from ..player.playlist import Playlist
from ..ui.library_dock import LibraryDock
from ..ui.playlist import PlaylistView


class Library:
    """
    Class that manages and syncs the library and library gui dock widgets.
    """

    def __init__(self, app):
        self.app = app

        self.main_library_dock = LibraryDock(self)
        self.library_docks = [self.main_library_dock]

        self.playlists = []
        self.temporary_playlist = None

    def load(self):
        self.load_playlists()

    def load_playlists(self):
        path_playlists = os.path.expanduser(f"{self.app.settings.library_path}/playlists")

        if not os.path.exists(path_playlists):
            os.makedirs(path_playlists)

            self.load_playlist_views()

            return

        folder_content = os.listdir(path_playlists)

        for file_name in folder_content:
            if file_name.endswith(".m3u"):
                path = f"{path_playlists}/{file_name}"

                playlist = Playlist(self.app, file_name.replace("_", " ").split(".")[0])
                self.playlists.append(playlist)

                if playlist.title == "Temporary Playlist":
                    self.temporary_playlist = playlist

    def load_playlist_views(self):
        for library_dock in self.library_docks:
            playlist_tabs: QTabWidget = library_dock.library_widget.playlist_tabs

            playlist_tabs.playlists = {}

            for playlist in self.playlists:
                playlist_view = PlaylistView(playlist, library_dock)
                playlist_tabs.addTab(playlist_view, playlist.title)

    def on_exit(self, event):
        for playlist in self.playlists:
            playlist.save()

        if self.app.player.current_playlist is not None:
            self.app.settings.latest_playlist = self.app.player.current_playlist.path

    def new_playlist(self):
        playlist = Playlist(self.app, self.app.utils.unique_name("New Playlist"))
        self.playlists.append(playlist)

        for library_dock in self.library_docks:
            playlist_tabs: QTabWidget = library_dock.library_widget.playlist_tabs

            playlist_view = PlaylistView(playlist, library_dock)
            playlist_tabs.addTab(playlist_view, playlist.title)

