#!/usr/bin/python3

from PyQt6.QtGui import QIcon
from PyQt6.QtWidgets import QToolBar, QLabel
from .track_progress_slider import TrackProgressSlider


class TrackControl(QToolBar):
    def __init__(self, app, parent=None):
        super().__init__(parent)

        self.app = app

        self.setWindowTitle("Track Control")

        self.play_icon = QIcon.fromTheme(QIcon.ThemeIcon.MediaPlaybackStart)
        self.pause_icon = QIcon.fromTheme(QIcon.ThemeIcon.MediaPlaybackPause)

        icon = QIcon.fromTheme(QIcon.ThemeIcon.MediaSkipBackward)
        self.previous_button = self.addAction(icon, "Previous")

        self.toggle_play_button = self.addAction(self.play_icon, "Play/Pause")

        icon = QIcon.fromTheme(QIcon.ThemeIcon.MediaPlaybackStop)
        self.stop_button = self.addAction(icon, "Stop")

        icon = QIcon.fromTheme(QIcon.ThemeIcon.MediaSkipForward)
        self.next_button = self.addAction(icon, "Next")

        self.progress_indicator = QLabel("0:00")
        self.addWidget(self.progress_indicator)

        self.track_progress_slider = TrackProgressSlider(app, self)
        self.addWidget(self.track_progress_slider)

        self.track_length_indicator = QLabel("0:00")
        self.addWidget(self.track_length_indicator)

        self.connect()
        self.on_track_change(None, None)

    def connect(self):
        self.previous_button.triggered.connect(self.previous_track)
        self.toggle_play_button.triggered.connect(self.toggle_playing)
        self.stop_button.triggered.connect(self.stop)
        self.next_button.triggered.connect(self.next_track)

    def previous_track(self):
        if self.app.player.current_playlist is not None and self.app.player.current_playlist.has_tracks():
            self.app.player.previous_track()

    def stop(self):
        if self.app.player.current_playlist is not None and self.app.player.current_playlist.has_tracks():
            self.app.player.stop()

    def next_track(self):
        if self.app.player.current_playlist is not None and self.app.player.current_playlist.has_tracks():
            self.app.player.next_track()

    def on_track_change(self, previous_track, track):
        if self.app.player.playing:
            duration = 0

            if track:
                duration = track.duration

            self.track_progress_slider.setRange(
                0,
                duration
            )

            self.track_length_indicator.setText(self.app.utils.format_time(duration))

            self.track_progress_slider.update_progress()

    def toggle_playing(self):
        if self.app.player.playing and self.app.player.paused:  # paused
            self.app.player.unpause()

        elif self.app.player.playing:  # playing
            self.app.player.pause()

        # stopped but tracks in the current playlist
        elif self.app.player.current_playlist is not None and self.app.player.current_playlist.has_tracks():
            self.app.player.start_playing()

        elif self.app.player.current_playlist is None:
            if self.app.settings.latest_playlist is not None:
                for playlist in self.app.library.playlists:  # get loaded playlist by the path of the latest playlist
                    if playlist.path == self.app.settings.latest_playlist:
                        self.app.player.start_playlist(playlist)

                        break

    def on_playstate_update(self):
        if self.app.player.playing:
            if self.app.player.paused:
                self.toggle_play_button.setIcon(self.play_icon)

            else:
                self.toggle_play_button.setIcon(self.pause_icon)

        else:
            self.toggle_play_button.setIcon(self.play_icon)

